`timescale 1ns / 10ps
`define PERIOD 10 
module top_tb();
reg sysclk;
reg rst;
wire n_rst;
wire lightR0, lightR1, lightG0, lightG1, lightB0, lightB1;
wire light;
wire [31:0] div_clk;
wire [7:0] phase0, phase1_r, phase1_g , phase1_b;
wire [7:0] duty0, duty1r, duty1g , duty1b;
wire phase_trig0, phase_trig1r, phase_trig1g, phase_trig1b;
wire duty_trig0, duty_trig1r, duty_trig1g, duty_trig1b;
assign n_rst = ~rst;

always #(`PERIOD/2) sysclk =! sysclk;

initial begin
sysclk = 1'b0;
rst = 1'b1;
#`PERIOD rst = 1'b0;
#(9999999999999 * `PERIOD) $stop;
end

    ripple_div rd0( .n_rst(n_rst), .sysclk(sysclk), .div(div_clk));
    phase_counter p0w( .enable(1'b1),  .phase_shift(8'd0),  .div_clk(div_clk), .duty_trig(duty_trig0),  .phase_trig(phase_trig0),  .duty(phase0));
    phase_counter p1r( .enable(1'b1),  .phase_shift(8'd0),  .div_clk(div_clk), .duty_trig(duty_trig1r), .phase_trig(phase_trig1r), .duty(phase1_r));
    phase_counter p1g( .enable(1'b1),  .phase_shift(8'd31), .div_clk(div_clk), .duty_trig(duty_trig1g), .phase_trig(phase_trig1g), .duty(phase1_g));
    phase_counter p1b( .enable(1'b1),  .phase_shift(8'd63), .div_clk(div_clk), .duty_trig(duty_trig1b), .phase_trig(phase_trig1b), .duty(phase1_b));
    
    LUT_sin LS0(  .phase_idx(phase0),   .data(duty0));
    LUT_sin LS1R( .phase_idx(phase1_r), .data(duty1r));
    LUT_sin LS1G( .phase_idx(phase1_g), .data(duty1g));
    LUT_sin LS1B( .phase_idx(phase1_b), .data(duty1b));

    // white 
    pwm pwm0(.rst(rst),  .enable(1'b1), .duty_trig(duty_trig0),  .phase_trig(phase_trig0),  .duty(duty0),  .out(light));
    pwm pwm1r(.rst(rst), .enable(1'b1), .duty_trig(duty_trig1r), .phase_trig(phase_trig1r), .duty(duty1r), .out(lightR1));
    pwm pwm1g(.rst(rst), .enable(1'b1), .duty_trig(duty_trig1g), .phase_trig(phase_trig1g), .duty(duty1g), .out(lightG1));
    pwm pwm1b(.rst(rst), .enable(1'b1), .duty_trig(duty_trig1b), .phase_trig(phase_trig1b), .duty(duty1b), .out(lightB1));




endmodule
